@@ -8,9 +8,10 @@ use UnazuSan;
 
 my $unazu_san = UnazuSan->new(
     host       => 'example.com',
-    password   => 'xxxxxxxx',
+    password   => 'xxxxxxxxxxx',
     enable_ssl => 1,
-    join_channels => [qw/test/],
+    join_channels => [qw/arcade/],
+    respond_all   => 1,
 );
 
 $unazu_san->on_message(
@@ -25,4 +26,11 @@ $unazu_san->on_message(
     },
 );
 
+$unazu_san->on_command(
+    help => sub {
+        my ($receive, @args) = @_;
+        $receive->reply('help '. ($args[0] || ''));
+    }
+);
+
 $unazu_san->run;
